use std::collections::HashMap;

use serde::Deserialize;

#[derive(Debug, Clone, Deserialize)]
pub struct Config {
    pub projects: HashMap<String, Project>,
}

#[derive(Debug, Clone, Deserialize)]
pub struct Project {
    pub name: String,
    pub description: String,
    pub website: Option<String>,
    pub documentation: Option<String>,
    pub since: Option<String>,
    pub contact: Option<ContactInfo>,
    pub sub: HashMap<String, Project>,
}

#[derive(Debug, Clone, Deserialize)]
pub struct ContactInfo {
    pub email: Option<String>,
}

impl Config {
    pub fn load(path: &str) -> Self {
        serde_yml::from_str(&std::fs::read_to_string(path).unwrap()).unwrap()
    }
}

impl Project {
    pub fn build(&self, card_id: &str) -> maud::PreEscaped<String> {
        let subcard_id = format!("{card_id}_sub");
        // todo : info

        maud::html!(
            div class="card" id=(card_id) {
                h3 { (self.name) };
                p { "Description" };
                button class="expand-button" onclick=(format!("toggleSubcards('{subcard_id}')")) { "Expand" };
                div class="subcards" id=(subcard_id) {
                    @for (id, prj) in &self.sub {
                        (prj.build(id))
                    }
                };
            };
        )
    }
}
